@@ -1,3 +1,10 @@
+"""
+================================
+Visual Working Memory - Paradigm
+================================
+
+"""
+
 import os
 import json
 import time
@@ -161,7 +168,9 @@ class BCIWebSocket(WebSocket):
     # ----------------------------------------------------------------------
     def on_open(self, evt):
         """"""
-        self.send({'action': 'register'})
+        self.send({'action': 'register',
+                   'mode': self.main._bci_mode,
+                   })
         print('Connected with dashboard.')
 
         if on_connect := getattr(self.main, 'on_connect', False):
@@ -179,17 +188,17 @@ class BCIWebSocket(WebSocket):
                 getattr(self.main, data['method'])(
                     *data['args'], **data['kwargs'])
 
-    # ----------------------------------------------------------------------
-    def on_close(self, evt):
-        """"""
-        window.location.replace(self.ip_.replace(
-            '/ws', '').replace('ws', 'http'))
+    # # ----------------------------------------------------------------------
+    # def on_close(self, evt):
+        # """"""
+        # window.location.replace(self.ip_.replace(
+            # '/ws', '').replace('ws', 'http'))
 
-    # ----------------------------------------------------------------------
-    def on_error(self, evt):
-        """"""
-        window.location.replace(self.ip_.replace(
-            '/ws', '').replace('ws', 'http'))
+    # # ----------------------------------------------------------------------
+    # def on_error(self, evt):
+        # """"""
+        # window.location.replace(self.ip_.replace(
+            # '/ws', '').replace('ws', 'http'))
 
 
 ########################################################################
@@ -332,6 +341,7 @@ class Feedback:
     def __init__(self, analyser, subscribe):
         """"""
         self.main = analyser
+        # self.main.listen_feedback_ = True
 
         self.main._feedback = self
         self.name = subscribe
@@ -346,13 +356,8 @@ class Feedback:
     # ----------------------------------------------------------------------
     def on_feedback(self, fn):
         """"""
-        # self._on_feedback = fn
         self.main.listen_feedbacks(fn)
 
-    # # ----------------------------------------------------------------------
-    # def on_feedback_filter(self):
-        # """"""
-
 
 ########################################################################
 class StimuliAPI(Pipeline):
@@ -373,10 +378,10 @@ class StimuliAPI(Pipeline):
         self.ws = BCIWebSocket(f'ws://{ip}:{port}/ws')
         self.ws.main = self
 
-        if self.listen_feedback_:
-            logging.warning('Rquesting consumer')
-            timer.set_timeout(lambda: self.ws.send(
-                {'action': 'consumer', }), 1000)
+        # if self.listen_feedback_:
+            # logging.warning('Requesting consumer')
+            # timer.set_timeout(lambda: self.ws.send(
+                # {'action': 'consumer', }), 1000)
 
     # ----------------------------------------------------------------------
     @property
@@ -393,8 +398,8 @@ class StimuliAPI(Pipeline):
             'latency': self._latency,
             # 'datetime': datetime.now().timestamp(),
         }
-
         if self.mode == 'stimuli' or force or self.DEBUG:
+            logging.warning(f'Marker: {marker["marker"]}')
             self.ws.send({
                 'action': 'marker',
                 'marker': marker,
@@ -408,13 +413,6 @@ class StimuliAPI(Pipeline):
 
         # print(f'MARKER: {marker["marker"]}')
 
-    # ----------------------------------------------------------------------
-    @DeliveryInstance.event
-    def start_record(self):
-        """"""
-        self.send_annotation('start_record')
-        timer.set_timeout(self._send_custom_annotations, 15000)
-
     # ----------------------------------------------------------------------
     def _send_custom_annotations(self):
         """"""
@@ -424,6 +422,13 @@ class StimuliAPI(Pipeline):
             description = f'{k.replace(prefix, "").capitalize()}: {data[k]}'
             self.send_annotation(description)
 
+    # ----------------------------------------------------------------------
+    @DeliveryInstance.event
+    def start_record(self):
+        """"""
+        self.send_annotation('start_record')
+        timer.set_timeout(self._send_custom_annotations, 15000)
+
     # ----------------------------------------------------------------------
     @DeliveryInstance.event
     def stop_record(self):
@@ -433,8 +438,8 @@ class StimuliAPI(Pipeline):
     # ----------------------------------------------------------------------
     def send_annotation(self, description, duration=0, force=False):
         """"""
-        logging.warning(f'Annotation: {description}')
         if self.mode == 'stimuli' or force or self.DEBUG:
+            logging.warning(f'Annotation: {description}')
             self.ws.send({
                 'action': 'annotation',
                 'annotation': {'duration': duration,
@@ -448,6 +453,7 @@ class StimuliAPI(Pipeline):
     def send_feedback(self, feedback, force=False):
         """"""
         if self.mode == 'stimuli' or force or self.DEBUG:
+            logging.warning(f'Feedback: {feedback}')
             self.ws.send({
                 'action': 'feedback',
                 'feedback': feedback,
@@ -463,7 +469,8 @@ class StimuliAPI(Pipeline):
     def _on_feedback(self, *args, **kwargs):
         """"""
         if kwargs['mode'] == 'analysis2stimuli' and kwargs['name'] == self._feedback.name:
-            self.feedback_listener_(**kwargs)
+            if self.mode == 'stimuli' or self.DEBUG:
+                self.feedback_listener_(**kwargs)
 
     # ----------------------------------------------------------------------
     # @DeliveryInstance.both
