@@ -56,6 +56,15 @@ class _delivery_instance:
 DeliveryInstance = _delivery_instance()
 
 
+########################################################################
+class Feedback:
+    """"""
+    # ----------------------------------------------------------------------
+
+    def __init__(self):
+        """Constructor"""
+
+
 ########################################################################
 class StimuliAPI(RadiantAPI):
     """Rename Randiant with a arand new class."""
